elephant.test.test_asset module — Elephant 0.5.0 documentation

# elephant.test.test_asset module

Unit tests for the ASSET analysis.

class `elephant.test.test_asset.` `AssetTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `test_cluster_correct`()
  `test_cluster_matrix_entries`()
  `test_cluster_symmetric`()
  `test_intersection_matrix`()
  `test_mask_matrix`()
  `test_sse_difference`()
  `test_sse_intersection`()
  `test_sse_relations`()
  `test_stretched_metric_2d_correct_stretching`()
  `test_stretched_metric_2d_equals_euclidean_if_stretch_1`()
  `test_stretched_metric_2d_size`()
  `test_stretched_metric_2d_symmetric`()

`elephant.test.test_asset.` `run`()

`elephant.test.test_asset.` `suite`()